From c35c064e0498db832a9440c5d031d5aaefd1f515 Mon Sep 17 00:00:00 2001
From: rsc <rsc>
Date: Tue, 28 Aug 2007 13:01:10 +0000
Subject: [PATCH] cmain -> bootmain

---
 bootasm.S  | 4 ++--
 bootmain.c | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/bootmain.c b/bootmain.c
index fe95fa3..61f9a2a 100644
--- a/bootmain.c
+++ b/bootmain.c
@@ -15,7 +15,7 @@
 void readseg(uint, uint, uint);
 
 void
-cmain(void)
+bootmain(void)
 {
   struct elfhdr *elf;
   struct proghdr *ph, *eph;
diff --git a/bootasm.S b/bootasm.S
index 7abcb29..1831604 100644
--- a/bootasm.S
+++ b/bootasm.S
@@ -67,9 +67,9 @@ protcseg:
   
   # Set up the stack pointer and call into C.
   movl    $start, %esp
-  call cmain
+  call bootmain
 
   # If cmain returns (it shouldn't), loop.
 spin:
   jmp spin
 
@@ -67,9 +67,9 @@ protcseg:
 
-  # If cmain returns (it shouldn't), loop.
+  # If bootmain returns (it shouldn't), loop.
 spin:
   jmp spin